[![](https://img.shields.io/pypi/v/coherent.licensed)](https://pypi.org/project/coherent.licensed)

![](https://img.shields.io/pypi/pyversions/coherent.licensed)

[![](https://github.com/coherent-oss/coherent.licensed/actions/workflows/main.yml/badge.svg)](https://github.com/coherent-oss/coherent.licensed/actions?query=workflow%3A%22tests%22)

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

[![Coherent Software Development System](https://img.shields.io/badge/coherent%20system-informational)](https://github.com/coherent-oss/system)

